text stringlengths 12 1.05M | repo_name stringlengths 5 86 | path stringlengths 4 191 | language stringclasses 1
value | license stringclasses 15
values | size int32 12 1.05M | keyword listlengths 1 23 | text_hash stringlengths 64 64 |
|---|---|---|---|---|---|---|---|
#!/usr/bin/python
# -*- coding: utf-8 -*-
"""Tests for the preg front-end."""
import unittest
from dfvfs.helpers import source_scanner
from dfvfs.lib import definitions as dfvfs_definitions
from dfvfs.path import factory as path_spec_factory
from plaso.engine import knowledge_base
from plaso.frontend import preg
fr... | jorik041/plaso | tests/frontend/preg.py | Python | apache-2.0 | 7,243 | [
"BLAST"
] | 909176ca71f9afc9ce476e125e5065ca064a8d9426fc0b49ac5956c945fbd312 |
import json
import re
from collections import defaultdict
from datetime import datetime
import itertools as itertools
from django.conf import settings
from django.db import connection
from django.http import HttpResponse
from django.contrib.auth.models import User
from catmaid.models import UserRole, Treenode, Treen... | AdaEne/CATMAID | django/applications/catmaid/control/node.py | Python | gpl-3.0 | 31,266 | [
"NEURON"
] | 5f9a9f608b51d188f03fb32e9556f0c9302a3c1b95895f4a41836903d5b6f42e |
# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import with_statement
__all__ = ['toposort', 'CycleDetectedError', 'LoopDetectedError']
###################################################################
class CycleDetectedError(Exception): pass
class LoopDetectedError(Exception): pass... | xflows/clowdflows | workflows/toposort.py | Python | mit | 10,098 | [
"VisIt"
] | 4abb48b1cc7d51849e6946b86d14c7ec40299c1a0d0864c471243e9aba916c28 |
# Orca
#
# Copyright 2010 Consorcio Fernando de los Rios.
# Author: Javier Hernandez Antunez <jhernandez@emergya.es>
# Author: Alejandro Leiva <aleiva@emergya.es>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the ... | GNOME/orca | src/orca/settings_manager.py | Python | lgpl-2.1 | 25,142 | [
"ORCA"
] | 7fcdfa779baf61f55656d39d9d67b41fcf4ba8597513918673d6dc3f18a51d21 |
# Copyright 2013 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or ... | daafgo/CourseBuilder-Xapi | modules/oauth2/oauth2.py | Python | apache-2.0 | 7,343 | [
"VisIt"
] | 38c0faa734b5cedec46f284f0ffaff51e12f491b4143fd4505ce2e0ab79d5209 |
# Copyright (C) 2010-2019 The ESPResSo project
#
# This file is part of ESPResSo.
#
# ESPResSo is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later v... | KaiSzuttor/espresso | src/python/object_in_fluid/oif_utils.py | Python | gpl-3.0 | 22,024 | [
"ESPResSo",
"ParaView",
"VTK"
] | 6f08cd3a15d5cfee9c399e3497c76fa8f566523d8b881f656dec4b76eae43526 |
#!/usr/bin/env python
"""
Converts a PDB file to mmCIF format,
adding missing heavy atoms in the process.
"""
import argparse
from pdbfixer import PDBFixer
from simtk.openmm.app import PDBxFile
ap = argparse.ArgumentParser()
ap.add_argument('structure')
ap.add_argument('--output', default=None, help='Output name f... | csblab/md_scripts | utils/pdb2mmCIF.py | Python | mit | 870 | [
"OpenMM"
] | ef10751b267c0e0d890e0f91b00ff7872d21ee00603e23fb5c4b03718e19ce6b |
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2018 Piero Dalle Pezze
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the ... | pdp10/sbpipe | sbpipe/pl/ps1/parscan1.py | Python | mit | 18,423 | [
"COPASI"
] | e5311ddc78f3967683eb5baf13e2a96fc9f0fb2332a260d0fe246a1c5d2f7ce0 |
#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""Marking this test NOPASS because it fails ~50% of the times."""
from __future__ import print_function
import sys
sys.path.insert(1,"../../")
import h2o
from tests import pyunit_utils
import random
import os
def javapredict_dynamic_data():
# Generate random datase... | mathemage/h2o-3 | h2o-py/tests/testdir_javapredict/pyunit_NOPASS_javapredict_dynamic_data_paramsDL.py | Python | apache-2.0 | 3,572 | [
"Gaussian"
] | 8e9bdfa9661545d3033634a3fc20dce807c6033cc4ec91bbf86c2c4d460b1d3c |
"""
@name: Modules/Core/Utilities/update_tools.py
@author: D. Brian Kimmel
@contact: D.BrianKimmel@gmail.com
@copyright: (c) 2019-2020 by D. Brian Kimmel
@note: Created on Jan 11, 2019
@license: MIT License
@summary:
"""
__updated__ = '2019-12-30'
# Import system type stuff
# Import PyMh files
fr... | DBrianKimmel/PyHouse | Project/src/Modules/Core/Utilities/update_tools.py | Python | mit | 764 | [
"Brian"
] | 362d7e5bb1a9a8e1da7f9c909db65b03b6485ccf35a8cd3df54fd7b9a398eac1 |
"""
Tests which scan for certain occurrences in the code, they may not find
all of these occurrences but should catch almost all.
"""
from __future__ import division, absolute_import, print_function
import sys
import pytest
if sys.version_info >= (3, 4):
from pathlib import Path
import ast
import tokenize... | MSeifert04/numpy | numpy/tests/test_warnings.py | Python | bsd-3-clause | 2,594 | [
"VisIt"
] | dfc6c0b477343f6b99f1cd98f5342c7b793a281b4f9ef8b1f10ece945dd6819c |
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not us... | bravo-zhang/spark | examples/src/main/python/sql/datasource.py | Python | apache-2.0 | 8,448 | [
"COLUMBUS"
] | d5632958619703fec0edb7550838ada0c9dad7f665736f1c7c6a2c1c24b8a705 |
"""
Exponential Synapse Model with support for pre-synaptic connection
"""
from basesynapse import BaseSynapse
import numpy as np
import pycuda.gpuarray as garray
from pycuda.tools import dtype_to_ctype
import pycuda.driver as cuda
from pycuda.compiler import SourceModule
cuda_src_synapse_kernel = """
__global__ voi... | AdamRTomkins/libSpineML2NK | libSpineML2NK/synapses/ExpSynapsePre.py | Python | gpl-3.0 | 7,248 | [
"NEURON"
] | 95e14ba8a425821f7d0bcced9c235dc48744d2557cf28a1a53b61e108983e916 |
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.conf import settings
from django.conf.urls import include, url
from django.conf.urls.static import static
from django.contrib import admin
from django.views.generic import TemplateView
from django.views import defaults as default_views
urlpat... | nikkomidoy/project_soa | project_soa/urls.py | Python | mit | 1,546 | [
"VisIt"
] | fdee18e3a29d706413ea26615bae3810f10a0db5afb632599a99e3ff625f9bbe |
import numpy as np
import scipy as sp
import defaults as df
from math import sin, pi, cos
from matplotlib.pyplot import imshow, plot, show, draw, pause, clim, figure
import sys
from constants import *
transverse = []
longi = []
_transverse = 0
_longi = 0
#from matplotlib import figure
class Solver:
_transverse = 0... | akshayrangasai/nonlinear_FDTD | solver.py | Python | gpl-2.0 | 9,145 | [
"Gaussian"
] | 816b90e81992dbe9a88814e8f49696d41877effebffb7d99ff6b875e491116d0 |
#
# QAPI command marshaller generator
#
# Copyright IBM, Corp. 2011
#
# Authors:
# Anthony Liguori <aliguori@us.ibm.com>
# Michael Roth <mdroth@linux.vnet.ibm.com>
#
# This work is licensed under the terms of the GNU GPLv2.
# See the COPYING.LIB file in the top-level directory.
from ordereddict import OrderedDict... | HusterWan/qemu-1.7.2-stable | scripts/qapi-commands.py | Python | gpl-2.0 | 12,251 | [
"VisIt"
] | 1deb4b8c2325b031f864d3295801f8265d219f0e9339259a002961f39b08f1d2 |
import Utils
import os
from collections import defaultdict
import matplotlib.pyplot as plt
import pandas as pd
from random import Random
from Simulation import Simulation
import pylab, numpy, math, csv
def run_sim(params, exp_prefix, rng, sim=True):
"""
Run multiple initialisations of a single set of experime... | thorsilver/Modelling-academic-job-security | Main.py | Python | mit | 58,120 | [
"Gaussian"
] | e421b3698af79f6e1addb9efbb3afb2997a455ba39e5981b3da31fabf418d2c3 |
import numpy as np
import cv2
import imutils
import sys
from collections import deque
from scipy.misc import imread
import argparse
from scipy import signal
# use argument parser to parse arguments such as video
ap = argparse.ArgumentParser()
ap.add_argument("-v", "--video",
help="path to the (optional)... | ITCoders/Surveillance-System | scripts/LOG_Filter_video.py | Python | gpl-3.0 | 2,089 | [
"Gaussian"
] | b61f5ef0f703b71878cf7d6e0b856caa92f8f127f960b340657b75a4a9bc25d9 |
<<<<<<< HEAD
<<<<<<< HEAD
import gc
import sys
import unittest
import weakref
from test import support
class FinalizationTest(unittest.TestCase):
def test_frame_resurrect(self):
# A generator frame can be resurrected by a generator's finalization.
def gen():
nonlocal frame
... | ArcherSys/ArcherSys | Lib/test/test_generators.py | Python | mit | 163,481 | [
"VisIt"
] | ec83ff7d37aaeba1338bec05d46b24d11f9638c08807b7e6ed59cddca64c917b |
# Copyright 2014 by Melissa Gymrek <mgymrek@mit.edu>. All rights reserved.
# This code is part of the Biopython distribution and governed by its
# license. Please see the LICENSE file that should have been included
# as part of this package.
from Bio.PopGen.SimCoal.Controller import FastSimCoalController
from Bio im... | updownlife/multipleK | dependencies/biopython-1.65/Tests/test_PopGen_FastSimCoal.py | Python | gpl-2.0 | 1,976 | [
"Biopython"
] | adecd5b7627756595f8bfd191113eee9487be101e0e57602d70b0bfec49aa3c4 |
"""
This file is part of the KnownSourceMatcher.
KnownSourceMatcher is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
KnownSourceMatcher is d... | scienceguyrob/KnownSourceMatcher | KnownSourceMatcher/src/Match/PFDFile.py | Python | gpl-2.0 | 40,225 | [
"Gaussian"
] | 8ff71ae7dfab90128ab8aaa8200e6180591df7f767fc7415d87bf87fe811db0c |
"""
Get, read, and parse data from `PVGIS <https://ec.europa.eu/jrc/en/pvgis>`_.
For more information, see the following links:
* `Interactive Tools <https://re.jrc.ec.europa.eu/pvg_tools/en/tools.html>`_
* `Data downloads <https://ec.europa.eu/jrc/en/PVGIS/downloads/data>`_
* `User manual docs <https://ec.europa.eu/j... | anomam/pvlib-python | pvlib/iotools/pvgis.py | Python | bsd-3-clause | 10,882 | [
"EPW"
] | aa18b094a36c3521cbe972bd5a43986deb70c97f80e3b0480f11e82af9bb3e92 |
# This file is part of Androguard.
#
# Copyright (c) 2012 Geoffroy Gueguen <geoffroy.gueguen@gmail.com>
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://... | uTest/Androguard | androguard/decompiler/dad/basic_blocks.py | Python | apache-2.0 | 9,901 | [
"VisIt"
] | 36b82a0b5b4fefc422fdc90e275f2999614ddd23b32e961f21778fe9c22c3146 |
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#default_value:foo
#include: other.manifest
#
#[test_name.js]
# expected: ERROR
#
# [subtest 1]
# expected:
# ... | jgraham/manifest | manifest/manifest.py | Python | mpl-2.0 | 23,759 | [
"VisIt"
] | ea5bbe4a20165237a7ce2d13b77628a9a48e96b147b763cb3f6832b3b38f5af6 |
#!/usr/bin/env python
# Lint as: python2, python3
#
# Copyright 2006 The Closure Library Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apac... | GoogleChromeLabs/chromeos_smart_card_connector | third_party/closure-library/src/closure/bin/calcdeps.py | Python | apache-2.0 | 17,980 | [
"VisIt"
] | bd3fdfa063a163276b9fdc531743cc609ffd6446d9a43a11e2a1d9190f515f99 |
# This file is part of Shyft. Copyright 2015-2018 SiH, JFB, OS, YAS, Statkraft AS
# See file COPYING for more details **/
import os
import re
import numpy as np
from netCDF4 import Dataset
from shyft import api
from .. import interfaces
from .time_conversion import convert_netcdf_time
from .utils import _limit_2D, _sli... | jfburkhart/shyft | shyft/repository/netcdf/wrf_data_repository.py | Python | lgpl-3.0 | 10,164 | [
"NetCDF"
] | 018465d72f9773a5e9847cf3ff349932652bd5fc4f936fc00b5444f2ee644a70 |
# Orca
#
# Copyright 2004-2009 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This... | ruibarreira/linuxtrail | usr/lib/python3/dist-packages/orca/speech.py | Python | gpl-3.0 | 11,213 | [
"ORCA"
] | 59fd466d7c54606531de9c5fd7101d2b682e54c0dfd32bcab1538c3dcd6ad071 |
import base64
from io import BytesIO
import param
import panel as pn
with param.logging_level('CRITICAL'):
import plotly.graph_objs as go
from param.parameterized import bothmethod
from ..renderer import Renderer, MIME_TYPES, HTML_TAGS
from ...core.options import Store
from ...core import HoloMap
from .callbac... | ioam/holoviews | holoviews/plotting/plotly/renderer.py | Python | bsd-3-clause | 5,821 | [
"ORCA"
] | 735d800388f1a713c825ef5b1453485bcfc3d8bb1708c183b175b4964df34c38 |
import numpy as np
from NeuronNetwork import add_dirac_pulse
def simulate(net, duration, base_current=0, bg_lam=0, bg_scale=0):
"""
Simulates the given network in action for the given duration, graphing the neuron spikes of the
different layers.
"""
VS = [np.zeros([duration, net.layers[idx].N]) f... | lawrencejones/neuro | Exercise_4/neuro/NetworkSimulator.py | Python | gpl-3.0 | 1,113 | [
"NEURON"
] | c0c3dcaaea27cffa95f775742ae750a1c763aaaa6268f96260bf5246a7c877ae |
from common import *
from pandas import DataFrame
from scipy.interpolate import make_interp_spline
from scipy.stats import norm
from sklearn.linear_model import LinearRegression
from sklearn2pmml.pipeline import PMMLPipeline
from sklearn2pmml.preprocessing.scipy import BSplineTransformer
import numpy
# See https://n... | jpmml/jpmml-sklearn | pmml-sklearn/src/test/resources/extensions/bspline.py | Python | agpl-3.0 | 1,228 | [
"Gaussian"
] | bd452052882864415b9ae3b1f5ae1c56e2013cbb932bccd8b21b833f64bedbe1 |
#!/usr/bin/env python
from setuptools import setup, find_packages
setup(name='CoalhmmPipeline',
version='1.2',
description='',
author='Kasper Munch',
author_email='kaspermunch@birc.au.dk',
packages=find_packages(),
)
# import ez_setup
# ez_setup.use_setuptools()
# import sys, glob... | kaspermunch/CoalhmmPipeline | setup.py | Python | gpl-2.0 | 1,197 | [
"VisIt"
] | 21a346cf21df434af6dc6295fc2435e20095dcf1be06ee39aa1956301fc44aca |
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4
##
## Copyright (C) 2006-2007 Async Open Source <http://www.async.com.br>
## All rights reserved
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Fou... | andrebellafronte/stoq | stoqlib/reporting/test/reporttest.py | Python | gpl-2.0 | 1,910 | [
"VisIt"
] | d4c2da653ec9d5a82b155974f6ffa13dd720217ed25062ed8a46d762d5e23f96 |
"""
Classes and functions for easier management of the InstalledComponents database
"""
import six
import re
import datetime
from sqlalchemy import MetaData, Column, Integer, String, DateTime, create_engine, text
from sqlalchemy.engine.reflection import Inspector
from sqlalchemy.ext.declarative import declarative_base
... | DIRACGrid/DIRAC | src/DIRAC/FrameworkSystem/DB/InstalledComponentsDB.py | Python | gpl-3.0 | 43,361 | [
"DIRAC"
] | 038965445de84eb0625f7a65cb1f074892f29961f78660a72e0b77a484a7508a |
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (C) 2014 Universidade de Aveiro, DETI/IEETA, Bioinformatics Group - http://bioinformatics.ua.pt/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software F... | bioinformatics-ua/catalogue | emif/utils/literature_port/pm_to_list.py | Python | gpl-3.0 | 1,448 | [
"Biopython"
] | d6ab2314ade895696e862e3e0f61868e5c15e022ea5154d32eea6f418c3b9b0d |
"""
.. _tut_viz_stcs:
Visualize Source time courses
=============================
This tutorial focuses on visualization of stcs.
.. contents:: Table of Contents
:local:
Surface Source Estimates
------------------------
First, we get the paths for the evoked data and the time courses (stcs).
"""
import os
impo... | mne-tools/mne-tools.github.io | 0.17/_downloads/136a1deb96a04d9a64be12fae37a338d/plot_visualize_stc.py | Python | bsd-3-clause | 5,752 | [
"Mayavi"
] | fe128d2a71bd15c67d8a8892a90000748448bc3c6e33d141afda9f71ccff6d3c |
# In game help system.
# prints helpful information
def help_command(PC, location):
location_type = location['type']
if PC.helps == 0:
to_print = """
You are {}. The X marks you!
Keep typing HELP for context based help.
""".format(PC.name)
elif PC.helps == 1:
to_print = """
Type INV to access your i... | Eric-Matthews/Explore_RPG | d_help.py | Python | gpl-3.0 | 1,694 | [
"Brian"
] | a6468fa0d4fbb6d55f04f9b1f4f97d09f222bcce56914a6b40307e573a62a887 |
#!/usr/bin/env python
import re
import sys
import os
from os.path import join as pj
import argparse
from collections import defaultdict
known_types = {
"double" : "double",
"int" : "int32",
"size_t" : "uint32",
"ui32" : "uint32",
"float" : "float",
"string" : "string",... | alexeyche/dnn | scripts/generate_protos.py | Python | gpl-2.0 | 6,147 | [
"NEURON"
] | 97b78f4559998a204c6155c8fd1c6afdcb32eaf44fdf8d6db5a131453582e536 |
# Recorded script from Mayavi2
from numpy import array
try:
engine = mayavi.engine
except NameError:
from mayavi.api import Engine
engine = Engine()
engine.start()
if len(engine.scenes) == 0:
engine.new_scene()
# -------------------------------------------
from mayavi.modules.iso_surface import Is... | FreeON/spammpack | spammsand/water_to_duals/plot_y_15_water.py | Python | bsd-3-clause | 3,589 | [
"Mayavi",
"VTK"
] | 50019f52a7daffbdc55102c71f170c5fece98769b71fc92d47d25e6cf4230751 |
#!/usr/bin/env python
import numpy
import itertools
from pymatgen.core.lattice import Lattice
from pymatgen.core.operations import SymmOp
from pymatgen.core.structure import Structure
from crystal import fillcell, tikz_atoms
def cluster_Mn4():
a = 5.43
c = a/2*7/4
bcc = Lattice([[a/2,a/2,-c/2],[a/2,-a/2,... | ldamewood/figures | scripts/cluster.py | Python | mit | 1,462 | [
"CRYSTAL",
"pymatgen"
] | 2b957a89009f3ede4e208f6bd4fbe78463adb8a99f3796c0d80a29b3313187e3 |
#!/usr/bin/env python3
#* This file is part of the MOOSE framework
#* https://www.mooseframework.org
#*
#* All rights reserved, see COPYRIGHT for full restrictions
#* https://github.com/idaholab/moose/blob/master/COPYRIGHT
#*
#* Licensed under LGPL 2.1, please see LICENSE for details
#* https://www.gnu.org/licenses/lgp... | harterj/moose | modules/geochemistry/test/tests/time_dependent_reactions/add_feldspar.py | Python | lgpl-2.1 | 1,470 | [
"MOOSE"
] | 788bdadf64a1bab9db8e9598595809b48c580b82df0e0d41a1bb9818e514a4c9 |
#!/usr/bin/env python
# ECLAIR/src/ECLAIR/Statistical_performance/Gaussian_KDE_HDF5.py;
# Author: Gregory Giecold for the GC Yuan Lab
# Affiliation: Harvard University
# Contact: g.giecold@gmail.com; ggiecold@jimmy.harvard.edu
"""ECLAIR is a package for the robust and scalable
inference of cell lineages from gene... | GGiecold/ECLAIR | src/ECLAIR/Statistical_performance/Gaussian_KDE_HDF5.py | Python | mit | 13,561 | [
"Gaussian"
] | 00946e734e8a5b4b3fb69338d7ded231ef86f5874eae73650ee4b15e39e4df9c |
from django.db import models
from django.conf import settings
from django.contrib.sites.models import Site
from django.core.exceptions import ObjectDoesNotExist, PermissionDenied
from django.core.mail import EmailMultiAlternatives
from django.core.urlresolvers import reverse
from django.template.defaultfilters import s... | PhilLidar-DAD/geonode | geonode/datarequests/models/data_request_profile.py | Python | gpl-3.0 | 32,831 | [
"VisIt"
] | a0447e37668abef3307409dbd23d5db5a6611d4efa32c9e8cc14b1c662343032 |
# !usr/bin/env python2
# -*- coding: utf-8 -*-
#
# Licensed under a 3-clause BSD license.
#
# @Author: Brian Cherinka
# @Date: 2017-01-27 14:26:40
# @Last modified by: Brian Cherinka
# @Last Modified time: 2018-11-12 14:14:41
from __future__ import print_function, division, absolute_import
from flask import reques... | sdss/marvin | python/marvin/web/error_handlers.py | Python | bsd-3-clause | 4,532 | [
"Brian"
] | 418a1863a0cc2ab0e923d3a4cc47585663f1f709487498d97e4506c6f355bc49 |
try:
# Prefer setuptools if it exists - cleaner uninstall
from setuptools import setup
except ImportError:
from distutils.core import setup
import glob
import os.path
import re
import warnings
VERSION_FILE = '../common_src/version.ml'
VERSION_PATTERN = r'^let version = "(.*)"$'
def get_version():
"""... | matsen/pplacer | scripts/setup.py | Python | gpl-3.0 | 1,264 | [
"Biopython",
"Brian"
] | 3e2205127f94ee1a3212d95db1f0e14549eb1d5899c91c9b803ed2d886f5d731 |
# -*- coding:utf-8 -*-
# Copyright (c) 2015, Galaxy Authors. All Rights Reserved
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
#
# Author: wangtaize@baidu.com
# Date: 2015-04-21
import subprocess
import os
import time
import utils
import socket
from galaxy import ... | fxsjy/galaxy | test/integeration/test_job_case.py | Python | bsd-3-clause | 1,691 | [
"Galaxy"
] | 1125e7a0d142ddc9c369e0605b8df1278253eec1859fa18c696e5c6e5d44a590 |
""" TransformationAgent processes transformations found in the transformation database.
"""
import time, re, random, Queue, os, datetime, pickle
from DIRAC import S_OK, S_ERROR
from DIRAC.Core.Base.AgentModule import AgentModu... | fibbo/DIRAC | TransformationSystem/Agent/TransformationAgent.py | Python | gpl-3.0 | 26,912 | [
"DIRAC"
] | 538a5e46061fe8f4d7936c9706831a03ef1b2cd812d3ceb93f6907aa713d622d |
# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function, unicode_literals
import time
import unittest
import logging
import functools
from nose.tools import * # flake8: noqa (PEP8 asserts)
import mock
from framework.auth.core import Auth
from website import settings
import website.... | binoculars/osf.io | osf_tests/test_elastic_search.py | Python | apache-2.0 | 39,105 | [
"Brian"
] | 077635e038fb250c7ee72dd03397fc73fda000b6c5ca4575055a1433bc887fb7 |
# simple test of pair tool
# requires files/data.rhodo
p = pair("lj/charmm/coul/charmm")
d = data("files/data.rhodo")
p.coeff(d)
p.init(8.0,10.0)
ev,ec = p.single(5.0,1,2,0.5,-0.5)
print "Energies",ev,ec
print "all done ... type CTRL-D to exit Pizza.py"
| baoboa/pizza-lammps | examples/test_pair.py | Python | gpl-2.0 | 256 | [
"CHARMM"
] | 2190a4099ef41eea499ccb6b824391a45b2b2573560414352e94378c9c441d96 |
# Copyright (C) 2011-2012 CRS4.
#
# This file is part of Seal.
#
# Seal is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Seal is dis... | crs4/seal | tests/tseal/lib/aligner/bwa/testing_utilities.py | Python | gpl-3.0 | 8,948 | [
"BWA",
"Biopython"
] | 9645b2c42df0ef1812499eafcba6912983335fd8ead227d4feb5962c10229b2f |
# Copyright 2016 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applica... | natanielruiz/android-yolo | jni-build/jni/include/tensorflow/contrib/distributions/python/ops/normal.py | Python | apache-2.0 | 12,706 | [
"Gaussian"
] | 39260132f9941d935b4c5929afebc23f83388e08d2a72941486272e8be1bcde4 |
# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, the cclib development team
#
# This file is part of cclib (http://cclib.github.io) and is distributed under
# the terms of the BSD 3-Clause License.
import os
import unittest
import numpy
from cclib.bridge import cclib2openbabel
class OpenbabelTest(unittest.TestCase)... | ATenderholt/cclib | test/bridge/testopenbabel.py | Python | bsd-3-clause | 2,105 | [
"cclib"
] | 74c5a3d810b0886dad846ab7fad0dd3bfe20bcea3a39bdf40ce424c5ec99bfed |
#!/usr/bin/env python
#
# original filename: meanmed.py
#
# Author: Tim Brandt
# email: tbrandt@astro.princeton.edu
# Date: July 2012
#
# Description: Implement the mean/median hybrid estimator described in
# Brandt+ (2012). Combine an image sequence using the optimal estimator
# at each separation from the central st... | t-brandt/acorns-adi | combine/meanmed.py | Python | bsd-2-clause | 3,883 | [
"Gaussian"
] | ac17b6c72718cdd504336114a725e22c0b35d023ecd217e27685713c6c08c61b |
import ast, _ast, sys, os
inc_path = os.path.expanduser("~") + "/.medusa/lib/"
dartImports = []
dartLocalVars = []
dartClassVars = []
dartGlobalVars = []
pyGlobalVars = []
pyClasses = []
pyInbuilts = ['abs',
'all',
'any',
'bin',
'dict',
'file',
... | apoorv2404/medusa | bin/transform.py | Python | bsd-3-clause | 25,066 | [
"VisIt"
] | 586740a4c48f5342419bb34b2e192bc6be96d4f185074df785562f2cec2c9bd7 |
#!/usr/bin/env python
# =============================================================================
# MODULE DOCSTRING
# =============================================================================
"""
Test pipeline functions in pipeline.py.
"""
# =================================================================... | pgrinaway/yank | Yank/tests/test_pipeline.py | Python | lgpl-3.0 | 1,821 | [
"OpenMM"
] | 0ad4ec2e783dbf268a6b0d6b09efdd1b143667bbb31e8c4bac7983a2187359c7 |
"""
This is only meant to add docs to objects defined in C-extension modules.
The purpose is to allow easier editing of the docstrings without
requiring a re-compile.
NOTE: Many of the methods of ndarray have corresponding functions.
If you update these docstrings, please keep also the ones in
core/fromnum... | dwillmer/numpy | numpy/add_newdocs.py | Python | bsd-3-clause | 224,686 | [
"Brian"
] | 914800641df1d05eedd2828858efa3a034bccb339bf903495e943abf107e7559 |
#! /usr/bin/env python
########################################################################
# $HeadURL$
# File : dirac-admin-bdii-site
# Author : Adria Casajus
########################################################################
"""
Check info on BDII for CE
"""
__RCSID__ = "$Id$"
from DIRAC import exit a... | avedaee/DIRAC | Core/scripts/dirac-admin-bdii-ce.py | Python | gpl-3.0 | 1,461 | [
"DIRAC"
] | 3ea2454995b3a7ab2221814e76b023be051a007994c364513ee2bf7edb15018f |
"""An action to open various source files.
"""
# Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
# Copyright (c) 2005-2008, Enthought, Inc.
# License: BSD Style.
# Standard library imports.
from os.path import isfile
import new
# Enthought library imports.
from traits.api import Instance, Str
from pyface.api imp... | liulion/mayavi | mayavi/action/sources.py | Python | bsd-3-clause | 3,708 | [
"Mayavi"
] | 3522614fa9a80040d792df2fd4c8814842e9a83b44ff7d0c7dcdaba19e2fba65 |
#! /usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless requi... | googleapis/python-secret-manager | scripts/fixup_secretmanager_v1_keywords.py | Python | apache-2.0 | 6,743 | [
"VisIt"
] | 39709d98ba63e65a580cfb17854e5f46049f1ddf421c282beb2e30d4f03b0f57 |
from copy import deepcopy
import logging
from math import floor
import os
from os.path import join as pjoin
import warnings
from warnings import warn
import numpy as np
import nibabel as nib
from mayavi import mlab
from mayavi.tools.mlab_scene_model import MlabSceneModel
from mayavi.core import lut_manager
from maya... | Eric89GXL/PySurfer | surfer/viz.py | Python | bsd-3-clause | 143,648 | [
"Mayavi",
"VTK"
] | fcb7fefc3994940bfa0d7e74ea954b10b468df3f9f4f691d36afcab97d48c893 |
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2008 Brian G. Matherly
# Copyright (C) 2008 Jerome Rapinat
# Copyright (C) 2008 Benny Malengier
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Fre... | arunkgupta/gramps | gramps/gen/filters/rules/_hasgallerybase.py | Python | gpl-2.0 | 2,532 | [
"Brian"
] | c192db56d709c127b862e9c82200752e30f1268e19b273bb76883f0a48257eae |
from time import time
import sys
import numpy as np
from gpaw import parsize, parsize_bands
from gpaw.grid_descriptor import GridDescriptor
from gpaw.fd_operators import Laplace
from gpaw.mpi import world
B = parsize_bands # number of blocks
G = 120 # number of grid points (G x G x G)
N = 2000 # number of ban... | qsnake/gpaw | oldtest/parallel/bandpar1.py | Python | gpl-3.0 | 4,167 | [
"GPAW"
] | 15ff4e69b869e9f26a8988f27919714fc9f845cda61c5cfef15890aad3ef097d |
from osgeo import ogr
ds = ogr.Open(r'D:\osgeopy-data\Galapagos')
lyr = ds.GetLayerByName('albatross_ranges2')
lyr.SetAttributeFilter("tag_id = '1163-1163' and location = 'island'")
row = next(lyr)
all_areas = row.geometry().Clone()
common_areas = row.geometry().Clone()
for row in lyr:
all_areas = all_areas.Union(... | cgarrard/osgeopy-code | Chapter7/listing7_10.py | Python | mit | 529 | [
"VisIt"
] | 174f98acb378b08acc2f734c897631dca758458efc03657bf3175a204aa9deea |
"""Support for Konnected devices."""
import asyncio
import copy
import hmac
import json
import logging
from aiohttp.hdrs import AUTHORIZATION
from aiohttp.web import Request, Response
import voluptuous as vol
from homeassistant import config_entries
from homeassistant.components.binary_sensor import DEVICE_CLASSES_SC... | turbokongen/home-assistant | homeassistant/components/konnected/__init__.py | Python | apache-2.0 | 14,276 | [
"VisIt"
] | d9bacb1224a5b5ce8f81dc84fae9047ee67aae404c43de34cf9beba0f5e2e680 |
# plugin: com.py
# Copyright (c) 2010 Oliver Beckstein <orbeckst@gmail.com>
# Released under the GNU Public License 3 (or higher, your choice)
# See the file COPYING for details.
"""
Centre of mass
==============
Calculate the centre of mass of index groups.
Plugin class
------------
.. autoclass:: COM
:members:... | jandom/GromacsWrapper | gromacs/analysis/plugins/com.py | Python | gpl-3.0 | 9,907 | [
"Gromacs"
] | 0cb9f0e2d9ec8ebe5249cf05ab5afc6cd44bf9cd8a51a890bc4fe15957b3fdaf |
#!/usr/bin/env python
# Copyright 2015 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
import idl_schema
import json_parse
from js_externs_generator import JsExternsGenerator
from datetime import datetime
import model
impo... | mou4e/zirconium | tools/json_schema_compiler/js_externs_generator_test.py | Python | bsd-3-clause | 7,390 | [
"exciting"
] | 2b923ec40a39257ae5964fb78f1c47ec048e2a7af6ccc4cb2fc118a151bc4946 |
import Briefing
import Director
import VS
import debug
import faction_ships
import launch
import quest
import universe
import unit
import vsrandom
from go_to_adjacent_systems import *
from go_somewhere_significant import *
class defend (Director.Mission):
""" Defend a base and/or a flightgroup from enemies and ea... | ermo/privateer_wcu | modules/missions/defend.py | Python | gpl-2.0 | 9,205 | [
"VisIt"
] | 737a5bba035eea462c1ef9bffc74ccd360ea531713f355ff6541008bc3dfd867 |
"""
Sequence distance metrics (:mod:`skbio.sequence.distance`)
==========================================================
.. currentmodule:: skbio.sequence.distance
This module contains functions for computing distances between scikit-bio
``Sequence`` objects. These functions can be used directly or supplied to other... | kdmurray91/scikit-bio | skbio/sequence/distance.py | Python | bsd-3-clause | 5,229 | [
"scikit-bio"
] | ffaecb3f811e4fcf2b205ab18c8ec317d4f7cf87066f7e0a0bbcf74d20d9e612 |
from __future__ import annotations
import sys
from unittest import mock
import pytest
from dials.util import Sorry
@pytest.mark.parametrize("name", ("foo_001", "_foo_001", "foo", "_foo_", "_1foo"))
def test_validate_project_crystal_name(name, ccp4, tmpdir):
with tmpdir.as_cwd():
with mock.patch.object(... | xia2/xia2 | tests/Handlers/test_CommandLine.py | Python | bsd-3-clause | 962 | [
"CRYSTAL"
] | 711c99afbf03277d718bb2112d966716f357ec37ad360ea7fa6ea1b439d22d8f |
#!/usr/bin/env python
#
# $File: HeteroMatingVSP.py $
#
# This file is part of simuPOP, a forward-time population genetics
# simulation environment. Please visit http://simupop.sourceforge.net
# for details.
#
# Copyright (C) 2004 - 2010 Bo Peng (bpeng@mdanderson.org)
#
# This program is free software: you can redistr... | BoPeng/simuPOP | docs/HeteroMatingVSP.py | Python | gpl-2.0 | 1,725 | [
"VisIt"
] | 3cc7e9162a66928b08da6ec817298ee06e0a5fbe7afe2450d9f002e2680e4225 |
"""
Top level inception api
"""
__all__ = ['floodfill','poissonblend','scale', 'magic_insert', 'inception']
from .image import Image
from .image.operation.floodfill import FloodfillOperation
from .image.operation.scale import ScaleOperation
from .image.operation.poisson import PoissonOperation
from .image.operation.me... | jercytryn/inception | src/inception/base.py | Python | mit | 13,330 | [
"Gaussian"
] | 7d1a438d27ca3359e776a63d237999d0501ae022da6ee5e16695e70f48a8a82f |
from __future__ import print_function
import time, gzip, random, os, sys
from rdkit import Chem
from rdkit.Chem import AllChem
from rdkit.Chem import Recap
from rdkit.RDLogger import logger
logger = logger()
tests = [1] * 1001
if len(sys.argv) > 1:
tests = [0] * 1001
tests[1] = 1
for x in sys.argv[1:]:
x = ... | rvianello/rdkit | Regress/Scripts/timings.py | Python | bsd-3-clause | 5,803 | [
"RDKit"
] | 1b874e08f68d1c4e0b7bebf3edd3bba832130a544e594600c9b58ce72b41de55 |
#!/usr/bin/env python
import bisect, os, sys, getopt, infodata, glob
import scipy, scipy.signal, ppgplot
import numpy as Num
from presto import rfft, next2_to_n
from psr_utils import coord_to_string
from optparse import OptionParser
from Pgplot import *
class candidate:
def __init__(self, DM, sigma, time, bin, dow... | pscholz/presto | bin/single_pulse_search.py | Python | gpl-2.0 | 30,794 | [
"Gaussian"
] | 891f43314212321e5d48f41f375f6fc994c33cb6504590c6f055119916aec758 |
"""
Download topo and dtopo files needed for this example.
Call functions with makeplots==True to create plots of topo, slip, and dtopo.
"""
from __future__ import print_function
import os,sys
import clawpack.clawutil.data
from clawpack.geoclaw import topotools
from numpy import *
# Center of Gaussian f... | clawpack/adjoint | examples/adjoint_CrescentCity_26hrs/make_qinit_adjoint.py | Python | bsd-2-clause | 1,079 | [
"Gaussian"
] | 5ed98ea2a85265247b3eb88d263946650a71a46d56c74aadede74a85ab4a5712 |
# -*- coding: utf-8 -*-
""" Mutual Information
Mutual Information (*MI*),
|
-----
.. [Vinck2011] Vinck, M., Oostenveld, R., van Wingerden, M., Battaglia, F., & Pennartz, C. M. (2011). An improved index of phase-synchronization for electrophysiological data in the presence of volume-conduction, noise and sample-si... | makism/dyfunconn | dyconnmap/fc/mui.py | Python | bsd-3-clause | 2,398 | [
"Gaussian"
] | a47fd3099a581a5150544bf24c903e4bf1f5f443e8831313b39279cf1d267771 |
#!/usr/bin/env python
import sys
import vtk
from vtk.test import Testing
from vtk.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()
# Prevent .pyc files being created.
# Stops the vtk source being polluted
# by .pyc files.
sys.dont_write_bytecode = True
import backdrop
# Contour every quadratic cell t... | HopeFOAM/HopeFOAM | ThirdParty-0.1/ParaView-5.0.1/VTK/Filters/Core/Testing/Python/contourQuadraticCells.py | Python | gpl-3.0 | 35,223 | [
"VTK"
] | d0da27d3f9855aceb00e35b4675d7b33291cebed5ce870b9b9f23610487a5dab |
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4
##
## Copyright (C) 2013 Async Open Source <http://www.async.com.br>
## All rights reserved
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundati... | andrebellafronte/stoq | stoq/gui/test/test_launcher.py | Python | gpl-2.0 | 2,860 | [
"VisIt"
] | 18fdca3db0248e743f3eb15630c73cbb25e041215f7d3c9b75ee500193e4f9f3 |
'''
Calling a JSON API
In this assignment, you will write a Python program somewhat similar to
http://www.py4e.com/code3/geojson.py. The program will prompt for a location,
contact a web service and retrieve JSON for the web service and parse that data,
and retrieve the first place_id from the JSON. A place ID is a te... | hosseinoliabak/learningpy | 13_51_googleApi.py | Python | gpl-3.0 | 2,968 | [
"VisIt"
] | c1a7b6ec11f7d3840b0dc634ded4082e481791877f4989acbd104fd5b099bd50 |
# -*- coding: utf-8 -*-
'''
Created on 13.11.2010
@author: tobias
'''
import numpy
class Planet(object):
'''
A Planet-Object stores all relevant information which are relevant
for calculating the galaxy.
'''
id = 0
mass = 0.0
radius = 0.0
posVector = numpy.array([0,0,0])
veloVect... | tscholze/ts-py-planet-sim | stable/Planet.py | Python | mit | 1,659 | [
"Galaxy"
] | cddd1b8e831b709caafe932fdb07a1197f703d9946ce026fdf31566a91eb5ac7 |
#!/usr/bin/env python
# lammps.py (2011/03/29)
# An ASE calculator for the LAMMPS classical MD code available from
# http://lammps.sandia.gov/
# The environment variable LAMMPS_COMMAND must be defined to point to the LAMMPS binary.
#
# Copyright (C) 2009 - 2011 Joerg Meyer, joerg.meyer@ch.tum.de
#
# This library... | JConwayAWT/PGSS14CC | lib/python/multimetallics/ase/calculators/lammps.py | Python | gpl-2.0 | 31,155 | [
"ASE",
"LAMMPS"
] | 150e5b147efedb25049a1293e95f3fdc04feca59b5477bc3e3812ae3559dfc2f |
#
# Copyright (C) 2008 Greg Landrum
#
# @@ All Rights Reserved @@
# This file is part of the RDKit.
# The contents are covered by the terms of the BSD license
# which is included in the file license.txt, found at the root
# of the RDKit source tree.
#
import re
from rdkit.Chem.Draw.canvasbase import CanvasBase
... | ptosco/rdkit | rdkit/Chem/Draw/spingCanvas.py | Python | bsd-3-clause | 3,615 | [
"RDKit"
] | 48107be738a2eda932ffa157d1c5027650fe33caa022eca91b18eb441abcb489 |
from django.conf.urls import url, include
from crystal_dashboard.dashboards.crystal.projects import views
from crystal_dashboard.dashboards.crystal.projects.groups import urls as groups_urls
urlpatterns = [
url(r'^$', views.IndexView.as_view(), name='index'),
url(r'groups/', include(groups_urls, namespace="gro... | Crystal-SDS/dashboard | crystal_dashboard/dashboards/crystal/projects/urls.py | Python | gpl-3.0 | 330 | [
"CRYSTAL"
] | 66995ec321ff88c8d8df5b490bf482e4c41c8cc183d5817187bdfac3d06c1ec4 |
from __future__ import absolute_import
from galaxy.web.base.controller import *
from galaxy.web.framework.helpers import time_ago, iff, grids
from galaxy.model.orm import *
from galaxy import model, util
from galaxy.web.form_builder import *
from .requests_common import RequestsGrid, invalid_id_redirect
from galaxy im... | mikel-egana-aranguren/SADI-Galaxy-Docker | galaxy-dist/lib/galaxy/webapps/galaxy/controllers/requests_admin.py | Python | gpl-3.0 | 47,292 | [
"Galaxy"
] | d700e6d02b991e0418d9a9b404e7fbb878e970d32dd4a74b0f4189b30fec32cd |
#
# Copyright 2018-2020 Universidad Complutense de Madrid
#
# This file is part of PyEmir
#
# SPDX-License-Identifier: GPL-3.0+
# License-Filename: LICENSE.txt
#
"""
Rectification and wavelength calibration polynomials from arc image
"""
from __future__ import division
from __future__ import print_function
import ar... | guaix-ucm/pyemir | emirdrp/processing/wavecal/rectwv_coeff_from_arc_image.py | Python | gpl-3.0 | 32,664 | [
"Gaussian"
] | cb792835577acfa894f9001760db45f50b399c7d98303a01858922e7990ba578 |
# coding=utf-8
# Copyright 2021 The RecSim Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or... | google-research/recsim_ng | recsim_ng/entities/state_models/dynamic.py | Python | apache-2.0 | 41,146 | [
"Gaussian"
] | 4ea934123b6ac5f7566591a82dce8b9250b9b653fb8f64adba21ec3637dc26ca |
from gpaw.utilities import unpack
from gpaw.utilities.tools import tri2full
from ase.units import Hartree
import cPickle as pickle
import numpy as np
from gpaw.mpi import world, rank, MASTER
from gpaw.basis_data import Basis
from gpaw.setup import types2atomtypes
from ase.calculators.singlepoint import SinglePointCalcu... | ajylee/gpaw-rtxs | gpaw/lcao/tools.py | Python | gpl-3.0 | 13,545 | [
"ASE",
"GPAW"
] | 676223740e32c33608b0e8030bd20e14aeb8deb1ce92fc491a5bdd0ba91b3e09 |
# -*- coding: utf-8 -*-
# Copyright 2015, Google, Inc.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or... | JPO1/python-docs-samples | bigquery/samples/list_datasets_projects.py | Python | apache-2.0 | 3,280 | [
"VisIt"
] | f7699260f49080ef303c5bc5910674407143c11d23a31c2308257d97a4b00ed7 |
# This file is part of BurnMan - a thermoelastic and thermodynamic toolkit for
# the Earth and Planetary Sciences
# Copyright (C) 2012 - 2021 by the BurnMan team, released under the GNU
# GPL v2 or later.
from __future__ import absolute_import
from __future__ import print_function
import numpy as np
from scipy.ndimag... | geodynamics/burnman | burnman/utils/math.py | Python | gpl-2.0 | 15,589 | [
"Gaussian"
] | 5a57b8237ec4fb593fe2688b9c36667a0503217d66129a316860344786a6082b |
import os
from ase import *
from gpaw import GPAW, Mixer
from gpaw.atom.generator import Generator
from gpaw.atom.configurations import parameters
from gpaw import setup_paths
from gpaw.test import equal
from gpaw.mpi import world
atom = 'Ne'
setup_paths.insert(0, '.')
for xcname in ['GLLBSC','GLLB']:
if world.ra... | qsnake/gpaw | gpaw/test/ne_gllb.py | Python | gpl-3.0 | 912 | [
"ASE",
"GPAW"
] | 26c0077aedb481d04696cf018eeca724e5347fb712c48f8041b70ff5321f9fa2 |
#!/usr/bin/env python
# coding: utf-8
# Copyright (c) Pymatgen Development Team.
# Distributed under the terms of the MIT License.
"""
Script to plot density of states (DOS) generated by an FEFF run
either by site, element, or orbital
"""
from __future__ import division
__author__ = "Alan Dozier"
__credits__= "Anub... | johnson1228/pymatgen | pymatgen/cli/feff_plot_dos.py | Python | mit | 2,193 | [
"FEFF",
"pymatgen"
] | de118ed3e9f9edeefe4faee718323299ce704558976f8ff769dd3a3b98bea60b |
from cdo import Cdo
from tempfile import mkstemp
import os
from flyingpigeon.utils import drs_filename, get_variable, calc_grouping, sort_by_filename
from flyingpigeon import config
import logging
logger = logging.getLogger(__name__)
DIR_MASKS = config.masks_dir()
DIR_SHP = config.shapefiles_dir()
def countries():... | KatiRG/flyingpigeon | flyingpigeon/subset.py | Python | apache-2.0 | 12,349 | [
"NetCDF"
] | 70f6133e5bf22965b3ab73316551670ef19cdb8d1dfaa440149a3b81b3f0a77f |
__author__ = "Rick Sherman, Nitin Kumar"
__credits__ = "Jeremy Schulman"
import unittest2 as unittest
from nose.plugins.attrib import attr
from mock import MagicMock, patch, mock_open
import os
from lxml import etree
from ncclient.manager import Manager, make_device_handler
from ncclient.transport import SS... | JamesNickerson/py-junos-eznc | tests/unit/test_device.py | Python | apache-2.0 | 19,176 | [
"Firefly"
] | d627d0860de88985cdfa68645ab64c697d7135329fda1fe309d81eb97947a548 |
#!/usr/bin/env python
from ase import io
atoms = io.read('/home/ruan/Documents/ZnO_slab/aims.cif')
atoms.write('POSCAR", format = 'vasp')
| ttlbyte/scripts | cif2aims.py | Python | mit | 138 | [
"ASE",
"VASP"
] | b4c70e597916bc7b4dc297e83bc0097e9ae64622a809390cf1d33f9bb3cc61cc |
#
# Copyright (c) 2009-2015, Jack Poulson
# All rights reserved.
#
# This file is part of Elemental and is under the BSD 2-Clause License,
# which can be found in the LICENSE file in the root directory, or at
# http://opensource.org/licenses/BSD-2-Clause
#
import El
n0 = 100
n1 = 100
lambda1 = 3
lambda2 = 4
out... | birm/Elemental | examples/interface/EN.py | Python | bsd-3-clause | 2,714 | [
"Gaussian"
] | a26c8ff860618f436bb3e7bb9f354c65f3c9927c464a67fd5ac17d3f4a14817e |
from collections import defaultdict
from .irvisitor import IRVisitor
from .common import get_src_text
import logging
logger = logging.getLogger()
class LineNumberSetter(IRVisitor):
def __init__(self):
super().__init__()
def visit_UNOP(self, ir):
ir.lineno = self.current_stm.lineno
se... | ktok07b6/polyphony | polyphony/compiler/setlineno.py | Python | mit | 3,264 | [
"VisIt"
] | 783c518cff37b63a88c784d54ee43790178d8ac50e4dfb240ed494b37d6a48ec |
# coding: utf-8
# Copyright (c) Pymatgen Development Team.
# Distributed under the terms of the MIT License.
"""
Module for BondDissociationEnergies.
"""
import logging
import networkx as nx
from monty.json import MSONable
from pymatgen.analysis.fragmenter import open_ring
from pymatgen.analysis.graphs import Molec... | gmatteo/pymatgen | pymatgen/analysis/bond_dissociation.py | Python | mit | 21,254 | [
"pymatgen"
] | 217dc878384bcb7ee276254e0a02b72cc97abcc907e4700e85d1a69c0366893b |
import logging
from kalliope import SignalLauncher, Utils
from kalliope.core import NeuronModule
from kalliope.core.ConfigurationManager import SettingEditor, YAMLLoader
from kalliope.core.Models.settings.Stt import Stt
from kalliope.core.Models.settings.Trigger import Trigger
from kalliope.core.Models.settings.Tts im... | kalliope-project/kalliope | kalliope/neurons/settings/settings.py | Python | gpl-3.0 | 13,043 | [
"NEURON"
] | 285fc7f1c6c05fdd23857c709d84d61013003a74ad32e31c759ec9e5ab3b251f |
from __future__ import absolute_import
from __future__ import print_function
import sys, os, yaml, glob
import subprocess
import datetime
import time
import types
# Header levels
H1, H2, H3, H4, H5, H6 = 1, 2, 3, 4, 5, 6
# List styles
UL, OL = 0, 1
# Alignment
CENTER, LEFT, RIGHT = 'CENTER', 'LEFT', 'RIGHT'
def ... | senthil10/NouGAT | nougat/common.py | Python | mit | 9,260 | [
"BWA"
] | ffb9614b437f8cc8e6d6ab265f14e93ea3db0611843bc52e5e3a4ab07c2f975c |
# (c) 2012, Michael DeHaan <michael.dehaan@gmail.com>
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any lat... | mwarkentin/ansible | lib/ansible/utils/__init__.py | Python | gpl-3.0 | 40,973 | [
"VisIt"
] | 858ebc063dd44d842b151e22d0c8f02d57116038dc5b8abc8d4afcdb6a128608 |
herodict = {
1: "Anti-Mage",
2: "Axe",
3: "Bane",
4: "Bloodseeker",
5: "Crystal Maiden",
6: "Drow Ranger",
7: "Earthshaker",
8: "Juggernaut",
9: "Mirana",
11: "Shadow Fiend",
10: "Morphling",
12: "Phantom Lancer",
13: "Puck",
14: "Pudge",
15: "Razor",
16: ... | ThePianoDentist/fantasy-dota-heroes | fantasydota/lib/herodict.py | Python | apache-2.0 | 2,476 | [
"CRYSTAL",
"TINKER"
] | 8fe957f21aed20a20512fb6af2ccb13fb6671f2ca63c6ff024daf40b2aebfaf6 |
#
# Copyright (C) 2003-2008 Greg Landrum and Rational Discovery LLC
#
# @@ All Rights Reserved @@
# This file is part of the RDKit.
# The contents are covered by the terms of the BSD license
# which is included in the file license.txt, found at the root
# of the RDKit source tree.
#
""" Definitions for 2D Pharma... | bp-kelley/rdkit | rdkit/Chem/Pharm2D/Gobbi_Pharm2D.py | Python | bsd-3-clause | 1,901 | [
"RDKit"
] | 5ff9312b0788d9fcde57a8afe9db10bd1ad91a4e780dd0f5f482d63b4bb7932d |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.